@@ -444,12 +444,12 @@ fn platform_support_path(platform: &str, os_version: &str) -> Result<PathBuf> {
 
 extern "C" fn mount_callback(_dict: CFDictionaryRef, _arg: *mut libc::c_void) {}
 
-fn mount_developper_image(dev: *const am_device) -> Result<()> {
+fn mount_developer_image(dev: *const am_device) -> Result<()> {
     unsafe {
         let _session = ensure_session(dev);
         let ds_path = device_support_path(dev)?;
         let image_path = ds_path.join("DeveloperDiskImage.dmg");
-        debug!("Developper image path: {:?}", image_path);
+        debug!("Developer image path: {:?}", image_path);
         let sig_image_path = ds_path.join("DeveloperDiskImage.dmg.signature");
         let sig = fs::read(sig_image_path)?;
         let sig = CFData::from_buffer(&sig);
@@ -457,7 +457,7 @@ fn mount_developper_image(dev: *const am_device) -> Result<()> {
         let options = [
             (
                 CFString::from_static_string("ImageType"),
-                CFString::from_static_string("Developper").as_CFType(),
+                CFString::from_static_string("Developer").as_CFType(),
             ),
             (
                 CFString::from_static_string("ImageSignature"),
@@ -517,16 +517,14 @@ fn ensure_session(dev: *const am_device) -> Result<Session> {
             bail!("lost pairing")
         };
         mk_result(AMDeviceValidatePairing(dev))?;
-        mk_result(AMDeviceStartSession(dev))?;
-        Ok(Session(dev))
-        // debug!("ensure session 4 ({:x})", rv);
-        // if rv as u32 == 0xe800001d {
-        // Ok(Session(::std::ptr::null()))
-        // } else {
-        // mk_result(rv)?;
-        // Ok(Session(dev))
-        // }
-        //
+        let rv = AMDeviceStartSession(dev);
+        // kAMDSessionActiveError
+        if rv as u32 == 0xe800001d {
+            Ok(Session(::std::ptr::null()))
+        } else {
+            mk_result(rv)?;
+            Ok(Session(dev))
+        }
     }
 }
 
@@ -556,7 +554,7 @@ pub fn install_app<P: AsRef<Path>>(dev: *const am_device, app: P) -> Result<()>
             ::core_foundation::url::CFURL::from_file_system_path(CFString::new(path), 0, true);
         let options = [(
             CFString::from_static_string("PackageType"),
-            CFString::from_static_string("Developper").as_CFType(),
+            CFString::from_static_string("Developer").as_CFType(),
         )];
         let options = CFDictionary::from_CFType_pairs(&options);
         mk_result(AMDeviceSecureTransferPath(
@@ -581,8 +579,8 @@ pub fn install_app<P: AsRef<Path>>(dev: *const am_device, app: P) -> Result<()>
 
 fn start_remote_debug_server(dev: *const am_device) -> Result<c_int> {
     unsafe {
-        debug!("mount developper image");
-        mount_developper_image(dev)?;
+        debug!("mount developer image");
+        mount_developer_image(dev)?;
         debug!("start debugserver on phone");
         let _session = ensure_session(dev)?;
         let mut handle: *const c_void = std::ptr::null();
@@ -751,7 +749,7 @@ fn launch_app(dev: &IosSimDevice, app_args: &[&str], _envs: &[&str]) -> Result<(
     println!("{}", test_contents);
 
     let output: String = String::from_utf8_lossy(&output.stdout).to_string();
-    debug!("LLDB OUTPUT: {}", output);
+    debug!("lldb script: \n{}", output);
     // The stdout from lldb is something like:
     //
     // (lldb) attach 34163
@@ -764,18 +762,17 @@ fn launch_app(dev: &IosSimDevice, app_args: &[&str], _envs: &[&str]) -> Result<(
     //     0x1019cd003 <+3>: movq   %rsp, %rbp
     //     0x1019cd006 <+6>: andq   $-0x10, %rsp
     // Target 0: (Dinghy) stopped.
-    //
     // Executable module set to .....
     // Architecture set to: x86_64h-apple-ios-.
     // (lldb) continue
     // Process 34163 resuming
     // Process 34163 exited with status = 101 (0x00000065)
-    //
     // (lldb) quit
     //
     // We need the "exit with status" line which is the 3rd from the last
-    let lines: Vec<&str> = output.lines().rev().collect();
-    let exit_status_line = lines.get(2);
+    let lines: Vec<&str> = output.lines().filter(|line| line.trim().len() > 0).rev().collect();
+    let exit_status_line = lines.get(1);
+    debug!("exit status line: {:?}", exit_status_line);
     if let Some(exit_status_line) = exit_status_line {
         let words: Vec<&str> = exit_status_line.split_whitespace().rev().collect();
         if let Some(exit_status) = words.get(1) {
